@@ -4,7 +4,7 @@
  * GChemPaint library
  * plugin.cc 
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -41,13 +41,13 @@ gcpPlugin::~gcpPlugin ()
 
 void gcpPlugin::LoadPlugins ()
 {
-	GDir* dir = g_dir_open (LIBDIR"/gchempaint-unstable/plugins", 0, NULL);
+	GDir* dir = g_dir_open (PLUGINSDIR, 0, NULL);
 	if (dir ==  NULL) return;
 	const char* name;
 	while ((name = g_dir_read_name (dir))) {
 		if ((strcmp (name + strlen (name) - 3, ".so")))
 			continue;
-		name = g_strconcat (LIBDIR"/gchempaint-unstable/plugins/", name, NULL);
+		name = g_strconcat (PLUGINSDIR"/", name, NULL);
 		if (!dlopen (name, RTLD_NOW)) puts (dlerror());
 		g_free ((void*) name);
 	}
