@@ -4,7 +4,7 @@
  * GChemPaint library
  * view.h 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -68,7 +68,6 @@ public:
 	gchar* GetSmallFontName() {return m_sSmallFontName;}
 	PangoFontDescription* GetPangoFontDesc() {return m_PangoFontDesc;}
 	PangoFontDescription* GetPangoSmallFontDesc() {return m_PangoSmallFontDesc;}
-	void UpdateLabel(const gchar* label);
 	void OnDeleteSelection(GtkWidget* w);
 	void OnCopySelection(GtkWidget* w, GtkClipboard* clipboard);
 	void OnPasteSelection(GtkWidget* w, GtkClipboard* clipboard);
@@ -87,7 +86,9 @@ public:
 	xmlDocPtr BuildSVG ();
 	void EnsureSize ();
 	void Zoom (double zoom);
+	GdkPixbuf *BuildPixbuf (int resolution);
 	void ShowCursor (bool show);
+	void UpdateTheme ();
 
 	//Implementation
 private:
